TeXMode

Enum TeXMode 

pub enum TeXMode {
    Vertical,
    InternalVertical,
    Horizontal,
    RestrictedHorizontal,
    InlineMath,
    DisplayMath,
}
The mode the engine is currently in, e.g. horizontal mode or vertical mode.

Variants



Vertical

The mode the engine is in at the start of a document, outside of boxes or paragraphs



InternalVertical

The mode the engine is in inside a vertical box



Horizontal

The mode the engine is in inside a paragraph



RestrictedHorizontal

The mode the engine is in inside a horizontal box



InlineMath

The mode the engine is in inside an inline math box



DisplayMath

The mode the engine is in inside a display math box

Implementations

Source

impl TeXMode

pub fn is_vertical(&self) -> bool

Returns true if the mode is vertical or internal vertical

pub fn is_horizontal(&self) -> bool

Returns true if the mode is horizontal or restricted horizontal

pub fn is_math(&self) -> bool

Returns true if the mode is inline math or display math

pub fn h_or_m(&self) -> bool

Returns true if the mode is horizontal, restricted horizontal, inline math, or display math