pub enum TeXMode {
Vertical,
InternalVertical,
Horizontal,
RestrictedHorizontal,
InlineMath,
DisplayMath,
}Expand description
The mode the engine is currently in, e.g. horizontal mode or vertical mode.
Variants
Vertical
The mode the engine is in at the start of a document, outside of boxes or paragraphs
InternalVertical
The mode the engine is in inside a vertical box
Horizontal
The mode the engine is in inside a paragraph
RestrictedHorizontal
The mode the engine is in inside a horizontal box
InlineMath
The mode the engine is in inside an inline math box
DisplayMath
The mode the engine is in inside a display math box
Implementations
Sourceimpl TeXMode
impl TeXMode
Sourcepub fn is_vertical(&self) -> bool
pub fn is_vertical(&self) -> bool
Returns true if the mode is vertical or internal vertical
Sourcepub fn is_horizontal(&self) -> bool
pub fn is_horizontal(&self) -> bool
Returns true if the mode is horizontal or restricted horizontal