pub struct StomachData<ET: EngineTypes> {Show 24 fields
pub page: Vec<VNode<ET>>,
pub open_lists: Vec<NodeList<ET>>,
pub pagegoal: ET::Dim,
pub pagetotal: ET::Dim,
pub pagestretch: ET::Dim,
pub pagefilstretch: ET::Dim,
pub pagefillstretch: ET::Dim,
pub pagefilllstretch: ET::Dim,
pub pageshrink: ET::Dim,
pub pagedepth: ET::Dim,
pub prevdepth: ET::Dim,
pub spacefactor: i32,
pub topmarks: HMap<usize, TokenList<ET::Token>>,
pub firstmarks: HMap<usize, TokenList<ET::Token>>,
pub botmarks: HMap<usize, TokenList<ET::Token>>,
pub splitfirstmarks: HMap<usize, TokenList<ET::Token>>,
pub splitbotmarks: HMap<usize, TokenList<ET::Token>>,
pub page_contains_boxes: bool,
pub lastpenalty: i32,
pub prevgraf: u16,
pub in_output: bool,
pub deadcycles: usize,
pub vadjusts: Vec<VNode<ET>>,
pub inserts: Vec<(usize, Box<[VNode<ET>]>)>,
}Expand description
All the mutable data of the Stomach - i.e. the current page, the current list(s), etc.
TODO: should be overhauled; this is just a rough approximation of what needs to happen and can be made more efficient and more correct.
Fields
page: Vec<VNode<ET>>open_lists: Vec<NodeList<ET>>pagegoal: ET::Dimpagetotal: ET::Dimpagestretch: ET::Dimpagefilstretch: ET::Dimpagefillstretch: ET::Dimpagefilllstretch: ET::Dimpageshrink: ET::Dimpagedepth: ET::Dimprevdepth: ET::Dimspacefactor: i32topmarks: HMap<usize, TokenList<ET::Token>>firstmarks: HMap<usize, TokenList<ET::Token>>botmarks: HMap<usize, TokenList<ET::Token>>splitfirstmarks: HMap<usize, TokenList<ET::Token>>splitbotmarks: HMap<usize, TokenList<ET::Token>>page_contains_boxes: boollastpenalty: i32prevgraf: u16in_output: booldeadcycles: usizevadjusts: Vec<VNode<ET>>inserts: Vec<(usize, Box<[VNode<ET>]>)>Implementations
Sourceimpl<ET: EngineTypes> StomachData<ET>
impl<ET: EngineTypes> StomachData<ET>